<?php

/********************************************************************
 * 
 * 記事 登録処理
 * 　　POST :
 * 
 ********************************************************************/
//クローラー判定
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$isCrawler = preg_match('/bot|crawl|slurp|spider/i', $userAgent);
if ($isCrawler) {
  //とりあえず成功ということにしとく
  echo '{"status":"success"}';
  exit();
}

//共通処理呼び出し
$require_login = true; //ログイン必要
require_once("../common.php");

//入力値フィルタリング
$mode = filter_input(INPUT_POST, 'mode') ?? "post";

$id = filter_input(INPUT_POST, 'id', FILTER_SANITIZE_NUMBER_INT);

$created_at =  filter_input(INPUT_POST, 'created_at');
$title =  filter_input(INPUT_POST, 'title') ?? "";
$comment =  filter_input(INPUT_POST, 'comment') ?? "";
$comment = base64_decode($comment); //WAF対策

$tags =  filter_input(INPUT_POST, 'tags') ?? "";
$tags = str_replace("　", " ", $tags); //全角スペースを半角に
$tags = " " . $tags . " "; //前後に空欄を付与（完全一致検索用）

$pin =  filter_input(INPUT_POST, 'pin') ?? false;
$hidden =  filter_input(INPUT_POST, 'hidden') ?? false;
$nsfw =  filter_input(INPUT_POST, 'nsfw') ?? false;

$style =  filter_input(INPUT_POST, 'style') ?? 0;
$use_html =  true;
switch ($style) {
  case 1: //詳細記事
    $use_full_html = true;
    break;
  case 99: //固定ページ
    $use_full_html = true;
    if (!$id) {
      $hidden = true;
    }
    break;
  default:
    $use_full_html = false;
    break;
}


$sortList =  filter_input(INPUT_POST, 'sort') ?? "";
$removeimages = filter_input(INPUT_POST, "removeimages") ?? "";

$err_message = "";

if (!$created_at && !$comment && $mode != "sort") {
  //日付もコメントもない場合はエラー
  echo '{"status":"error","message":"パラメータが不正です。ファイルサイズが大きすぎる可能性があります。"}';
  exit;
}

//日時指定がない場合は現在日時を使用
if (!$created_at) {
  date_default_timezone_set('Asia/Tokyo'); // タイムゾーンを設定
  $created_at = date('Y-m-d H:i:s'); // 日時をフォーマット
}

//DEMO版対応
if ($DEMO_MODE) {
  //スクリプトコードを取り除く
  $comment = preg_replace('/<.*?a .*?>/i', "", $comment);
  $comment = preg_replace('/<.*?link .*?>/i', "", $comment);
  $comment = preg_replace('/<.*?script.*?>/i', "", $comment);
  $comment = preg_replace('/<.*?iframe.*?>/i', "", $comment);
  $comment = preg_replace('/action=/i', "", $comment);
  $comment = preg_replace('/rel=/i', "", $comment);
}

//トランザクション開始
try {
  $db->exec('begin Immediate');

  if ($mode == "sort") {

    //画像並び替えモード
    $idx = 0;
    $sorts = explode(";", $sortList); // ;区切りでソートしたい順にファイル名が渡される
    foreach ($sorts as $sort) {
      $stmt = $db->prepare('update images set sort = :sort Where file_name = :fileName');
      $stmt->bindValue(':sort',  $idx + 1);
      $stmt->bindValue(':fileName',  $sort);
      $result = $stmt->execute();
      $idx++;
    }
    $db->exec('commit');
    $db->close();

    $url = $PATH_INFO["url_dir"] . "view.php?id=$id";
    echo '{"status":"success", "id":' . $id . ', "url":"' . $url . '","image_index":' . $idx . '}';
    exit;
  }

  //IDが指定されている場合は編集モード
  if ($id) {
    $mode = "edit";
  } else {
    $mode = "post";
  }

  //ファイルの削除
  if (isset($removeimages)) {
    foreach (explode(' ', $removeimages) as $imageId) {
      if ($imageId != "") {
        $stmt = $db->prepare('SELECT * FROM images WHERE article_id = :id AND id = :imageId');
        $stmt->bindValue(':id',  $id);
        $stmt->bindValue(':imageId',  $imageId);
        $result = $stmt->execute();

        $row = $result->fetchArray();
        if ($row) {
          if (file_exists("../images/{$row["file_name"]}")) {
            unlink("../images/{$row["file_name"]}");
          }
          if (file_exists("../images/{$row["thumb_name"]}")) {
            unlink("../images/{$row["thumb_name"]}");
          }
          if (file_exists("../images/{$row["thumb_l_name"]}")) {
            unlink("../images/{$row["thumb_l_name"]}");
          }
          $stmt = $db->prepare('DELETE FROM images WHERE article_id = :id AND id = :imageId');
          $stmt->bindValue(':id', $id);
          $stmt->bindValue(':imageId', $imageId);
          $result = $stmt->execute();
        }
      }
    }
  }

  //記事　記録
  if ($mode == "post") { //新規
    $stmt = $db->prepare("INSERT INTO articles (title, comment, tags, created_at, pin, hidden, nsfw, use_html, use_full_html, style) VALUES (:title, :comment, :tags, :created_at, :pin, :hidden, :nsfw, :use_html, :use_full_html, :style)");
  } else { //編集
    $stmt = $db->prepare("Update articles set title=:title, comment=:comment, tags=:tags, created_at=:created_at, pin=:pin, hidden=:hidden, nsfw = :nsfw, use_html = :use_html, use_full_html = :use_full_html, style = :style where id=:id");
    $stmt->bindValue(':id', $id);
  }
  $stmt->bindValue(':title', $title);
  $stmt->bindValue(':comment', $comment);
  $stmt->bindValue(':created_at', $created_at);
  $stmt->bindValue(':use_html', $use_html ? 1 : 0);
  $stmt->bindValue(':use_full_html', $use_full_html ? 1 : 0);
  $stmt->bindValue(':style', $style);
  $stmt->bindValue(':tags', $tags);
  $stmt->bindValue(':pin', $pin ? 1 : 0);
  $stmt->bindValue(':hidden', $hidden ? 1 : 0);
  $stmt->bindValue(':nsfw', $nsfw ? 1 : 0);
  $result = $stmt->execute();

  if ($mode == "post") {
    $id = $db->lastInsertRowID();
  }

  //該当ログに紐づいている画像一覧から一番大きいimage_idを取得し、+1したものを新規IDとする
  $image_idx = $db->querySingle('SELECT MAX(image_id) AS maxSort FROM images WHERE article_id = ' . $id) + 1;
  if (!isset($image_idx)) {
    $image_idx = 1;
  }
  $sort_idx = $db->querySingle('SELECT MAX(sort) AS maxSort FROM images WHERE article_id = ' . $id) + 1;
  if (!isset($sort_idx)) {
    $sort_idx = 1;
  }

  //ファイルの追加
  if (isset($_FILES['images'])) {
    foreach ($_FILES['images']['tmp_name'] as $index => $tmpName) {
      $fileName = $_FILES['images']['name'][$index];
      $fileSize = $_FILES['images']['size'][$index];
      $fileName = preg_replace('/\.jpeg$/i', '.jpg', $fileName); //jpegをjpgに変更
      $extension = substr($fileName, strrpos($fileName, '.') + 1);
      $newFileName = "image_" . $id . "_" . $image_idx . "." .  strtolower($extension);
      $thumbFileName = "image_" . $id . "_" . $image_idx . ".jpg"; //サムネイルはJPG固定
      $sortList = str_replace($fileName, $newFileName, $sortList);

      require_once('imageEdit.php');
      //リサイズ
      $imginfo = createResizeImage($tmpName, $SETTING['resize_border'], $SETTING['resize_border'], "../images/$newFileName", 90);

      //大サムネイル作成
      $thumb_l_info = createResizeImage($tmpName, 900, 0, "../images/thumb_l_$thumbFileName", 80);

      //小サムネイル作成
      $thumb_info = createResizeImage($tmpName, 300, 300, "../images/thumb_$thumbFileName", 80);

      $stmt = $db->prepare("INSERT INTO images (article_id, image_id, sort, file_name, width, height, thumb_l_name, thumb_l_width, thumb_l_height, thumb_name, thumb_width, thumb_height ) " .
        "VALUES (:article_id, :image_id, :sort, :newFileName, :width, :height, :thumb_l_name, :thumb_l_width, :thumb_l_height,:thumb_name, :thumb_width, :thumb_height)");
      $stmt->bindValue(':article_id', $id);
      $stmt->bindValue(':image_id', $image_idx);
      $stmt->bindValue(':sort', $sort_idx);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':width', $imginfo['width']);
      $stmt->bindValue(':height', $imginfo['height']);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':width', $imginfo['width']);
      $stmt->bindValue(':height', $imginfo['height']);
      $stmt->bindValue(':thumb_l_name', 'thumb_l_' . $thumbFileName);
      $stmt->bindValue(':thumb_l_width', $thumb_l_info['width']);
      $stmt->bindValue(':thumb_l_height', $thumb_l_info['height']);
      $stmt->bindValue(':thumb_name', 'thumb_' . $thumbFileName);
      $stmt->bindValue(':thumb_width', $thumb_info['width']);
      $stmt->bindValue(':thumb_height', $thumb_info['height']);

      $result = $stmt->execute();

      $sort_idx++;
      $image_idx++;
    }
  }
  if (!$DEMO_MODE && isset($_FILES['movies'])) {
    foreach ($_FILES['movies']['tmp_name'] as $index => $tmpName) {
      $preview_fileName = $_FILES['movie_previews']['name'][$index];
      $preview_fileSize = $_FILES['movie_previews']['size'][$index];
      $preview_tmpName = $_FILES['movie_previews']['tmp_name'][$index];
      $preview_fileName = preg_replace('/\.jpeg$/i', '.jpg', $preview_fileName); //jpegをjpgに変更
      $movie_fileName = $_FILES['movies']['name'][$index];
      $extension = substr($_FILES['movies']['name'][$index], strrpos($_FILES['movies']['name'][$index], '.') + 1);
      $newFileName = "image_" . $id . "_" . $image_idx . "." .  strtolower($extension);
      $thumbFileName = "image_" . $id . "_" . $image_idx . ".jpg"; //サムネイルはJPG固定
      $sortList = str_replace($movie_fileName, $newFileName, $sortList);

      require_once('imageEdit.php');

      //$imginfo = createResizeImage($tmpName, $SETTING['resize_border'], $SETTING['resize_border'], "../images/$newFileName", 90);
      copy($tmpName, "../images/$newFileName");

      //大サムネイル作成
      $thumb_l_info = createResizeImage($preview_tmpName, 900, 0, "../images/thumb_l_$thumbFileName", 80);

      //小サムネイル作成
      $thumb_info = createResizeImage($preview_tmpName, 300, 300, "../images/thumb_$thumbFileName", 80);

      $stmt = $db->prepare("INSERT INTO images (article_id, image_id, sort, file_name, width, height, thumb_l_name, thumb_l_width, thumb_l_height, thumb_name, thumb_width, thumb_height, type ) " .
        "VALUES (:article_id, :image_id, :sort, :newFileName, :width, :height, :thumb_l_name, :thumb_l_width, :thumb_l_height,:thumb_name, :thumb_width, :thumb_height, :type)");
      $stmt->bindValue(':article_id', $id);
      $stmt->bindValue(':image_id', $image_idx);
      $stmt->bindValue(':sort', $sort_idx);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':width', $thumb_l_info['width']);
      $stmt->bindValue(':height', $thumb_l_info['height']);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':thumb_l_name', 'thumb_l_' . $thumbFileName);
      $stmt->bindValue(':thumb_l_width', $thumb_l_info['width']);
      $stmt->bindValue(':thumb_l_height', $thumb_l_info['height']);
      $stmt->bindValue(':thumb_name', 'thumb_' . $thumbFileName);
      $stmt->bindValue(':thumb_width', $thumb_info['width']);
      $stmt->bindValue(':thumb_height', $thumb_info['height']);
      $stmt->bindValue(':type', 'video');

      $result = $stmt->execute();

      $sort_idx++;
      $image_idx++;
    }
  }
  //ソート順の更新
  $idx = 1;
  $sorts = explode(";", $sortList);
  foreach ($sorts as $sort) {
    $stmt = $db->prepare('update images set sort = :sort Where file_name = :fileName');
    $stmt->bindValue(':sort',  $idx);
    $stmt->bindValue(':fileName',  $sort);
    $result = $stmt->execute();
    $idx++;
  }
  $db->exec('commit');

  //ATOM出力
  require_once("./feed.php");
  createFeed();
} catch (Exception $ex) {
  echo '{"status":"error","message","' . $ex->getMessage()  . '"}';
  exit;
} finally {
  $db->close();
}

//タグクラウド生成
require_once('./make_tagcloud.php');
createTagcloud("{$rel}$system_db_file");

//表示用URL
$url = $PATH_INFO["url_system_root"] . "/view.php?id=$id";


//結果を出力
echo '{"status":"success", "id":' . $id . ', "url":"' . $url . '","image_index":' . $image_idx . '}';
