<?php

/********************************************************************
 * 
 * 外部からの投稿受付処理
 * 　　POST :
 * 
 ********************************************************************/
//クローラー判定
$userAgent = $_SERVER['HTTP_USER_AGENT'] ?? "";
$isCrawler = preg_match('/bot|crawl|slurp|spider/i', $userAgent);
if ($isCrawler) {
  //とりあえず成功ということにしとく
  echo '{"status":"success"}';
  exit();
}

//共通処理呼び出し
$require_login = false; //ログイン不要
$no_nsfw_check = true; //NSFWチェック不要
require_once("../common.php");

//外部用APIキー管理
require_once("./external_token.php");

//認証処理として呼び出された場合の処理
$callback_url =  filter_input(INPUT_GET, 'callback');
if ($callback_url) {
  $app_title =  filter_input(INPUT_GET, 'app_title') ?? "";
  if ($app_title = "") {
    echo "パラメータが不正です";
    exit;
  }
  $db->close();
  //確認画面に移行
  $url = $PATH_INFO["system_request"];
  $url = str_replace("callback=", "call=", $url);
  $url = $url .= "&msg=" . urlencode("外部アプリケーション「{$app_title}」からの書き込みを許可しますか？") . "&force=true";
  header("Location: {$redirect_rel}login.php?request=" . $url);
  exit;
}

//外部認証承諾時
$call_url =  filter_input(INPUT_GET, 'call');
if ($call_url && $LOGIN) {
  //ログイン済みの場合はコールバック先にAPIキーを渡す
  $key = generateDisposableApiKey($rel);
  header("Location: $call_url?apikey=$key");
  exit;
}

//認証処理として呼び出された場合の処理2 TOKEN確認
$pin =  filter_input(INPUT_GET, 'pin');
if ($pin) {
  //外部ポストのAPIキー確認
  $db->close();
  if (!isApiKeyValid($rel, $pin)) {
    header('HTTP/1.0 403 Forbidden');
    echo "Invalid PIN";
    exit();
  } else {
    echo '{"status":"success", "display_name":"' . $SETTING['display_name'] . '"}';
    exit();
  }
}


//入力値フィルタリング
$created_at =  filter_input(INPUT_POST, 'created_at');
$title =  filter_input(INPUT_POST, 'title');
$comment =  filter_input(INPUT_POST, 'comment') ?? "";
$tags =  filter_input(INPUT_POST, 'tags') ?? "";
$tags = str_replace("　", " ", $tags); //全角スペースを半角に
$tags = " " . $tags . " "; //前後に空欄を付与（完全一致検索用）
$nsfw =  filter_input(INPUT_POST, 'nsfw') ?? false;
$use_html =  false;
$use_full_html =  false;
$err_message = "";

//ゲストデータ
$delete_key = filter_input(INPUT_POST, 'delete_key') ?? "";
$from_ip = $_SERVER["REMOTE_ADDR"];


//外部ポストのAPIキー確認
$token = filter_input(INPUT_POST, 'apikey') ?? "";
require_once("./external_token.php");
if (!isApiKeyValid($rel, $token)) {
  $db->close();
  header('HTTP/1.0 403 Forbidden');
  echo "Invalid API key";
  exit();
}

//日時指定がない場合は現在日時を使用
if (!$created_at) {
  date_default_timezone_set('Asia/Tokyo'); // タイムゾーンを設定
  $created_at = date('Y-m-d H:i:s'); // 日時をフォーマット
}
//タイトルがない場合は現在日時をタイトルに使用
if (!$title) {
  $title = $created_at;
}

//トランザクション開始
try {
  $db->exec('begin Immediate');

  //記事　記録
  $stmt = $db->prepare("INSERT INTO articles (title, comment, tags, created_at, pin, hidden, nsfw, use_html, use_full_html, from_ip, delete_key) VALUES (:title, :comment, :tags, :created_at, :pin, :hidden, :nsfw, :use_html, :use_full_html, :from_ip, :delete_key)");
  $stmt->bindValue(':title', $title);
  $stmt->bindValue(':created_at', $created_at);

  $stmt->bindValue(':use_full_html', $use_full_html ? 1 : 0);
  $stmt->bindValue(':tags', $tags);
  $stmt->bindValue(':pin', $pin ? 1 : 0);
  $stmt->bindValue(':hidden', $hidden ? 1 : 0);
  $stmt->bindValue(':nsfw', $nsfw ? 1 : 0);
  if ($delete_key != "") {
    $stmt->bindValue(':delete_key', password_hash($delete_key, PASSWORD_DEFAULT));

    //ゲストモードの場合HTMLタグを制限
    $use_html = false;
  }
  $stmt->bindValue(':use_html', $use_html ? 1 : 0);
  $stmt->bindValue(':comment', $comment);
  $stmt->bindValue(':from_ip', $from_ip);

  $result = $stmt->execute();

  $id = $db->lastInsertRowID();

  //該当ログに紐づいている画像一覧から一番大きいソート番号を取得し、+1したものを新規IDとする
  $image_idx = $db->querySingle('SELECT MAX(image_id) AS maxSort FROM images WHERE article_id = ' . $id) + 1;
  if (!isset($image_idx)) {
    $image_idx = 1;
  }

  //ファイルの追加
  if (isset($_FILES['images'])) {
    foreach ($_FILES['images']['tmp_name'] as $index => $tmpName) {
      $fileName = $_FILES['images']['name'][$index];
      $fileSize = $_FILES['images']['size'][$index];
      $fileName = preg_replace('/\.jpeg$/i', '.jpg', $fileName); //jpegをjpgに変更
      $extension = substr($fileName, strrpos($fileName, '.') + 1);
      $newFileName = "image_" . $id . "_" . $image_idx . "." .  strtolower($extension);
      $thumbFileName = "image_" . $id . "_" . $image_idx . ".jpg"; //サムネイルはJPG固定
      $sortList = str_replace($fileName, $newFileName, $sortList);

      require_once('imageEdit.php');
      //リサイズ
      $imginfo = createResizeImage($tmpName, 1980, 1980, "../images/$newFileName", 90);

      //大サムネイル作成
      $thumb_l_info = createResizeImage($tmpName, 900, 0, "../images/thumb_l_$thumbFileName", 80);

      //小サムネイル作成
      $thumb_info = createResizeImage($tmpName, 300, 300, "../images/thumb_$thumbFileName", 80);

      $stmt = $db->prepare("INSERT INTO images (article_id, sort, file_name, width, height, thumb_l_name, thumb_l_width, thumb_l_height, thumb_name, thumb_width, thumb_height ) " .
        "VALUES (:article_id, :sort, :newFileName, :width, :height, :thumb_l_name, :thumb_l_width, :thumb_l_height,:thumb_name, :thumb_width, :thumb_height)");
      $stmt->bindValue(':article_id', $id);
      $stmt->bindValue(':sort', $image_idx);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':width', $imginfo['width']);
      $stmt->bindValue(':height', $imginfo['height']);
      $stmt->bindValue(':newFileName', $newFileName);
      $stmt->bindValue(':width', $imginfo['width']);
      $stmt->bindValue(':height', $imginfo['height']);
      $stmt->bindValue(':thumb_l_name', 'thumb_l_' . $thumbFileName);
      $stmt->bindValue(':thumb_l_width', $thumb_l_info['width']);
      $stmt->bindValue(':thumb_l_height', $thumb_l_info['height']);
      $stmt->bindValue(':thumb_name', 'thumb_' . $thumbFileName);
      $stmt->bindValue(':thumb_width', $thumb_info['width']);
      $stmt->bindValue(':thumb_height', $thumb_info['height']);

      $result = $stmt->execute();


      $image_idx++;
    }
  }

  //ソート順の更新
  $idx = 1;
  $sorts = explode(";", $sortList);
  foreach ($sorts as $sort) {
    $stmt = $db->prepare('update images set sort = :sort Where file_name = :fileName');
    $stmt->bindValue(':sort',  $idx);
    $stmt->bindValue(':fileName',  $sort);
    $result = $stmt->execute();
    $idx++;
  }
  $db->exec('commit');

  //ATOM出力
  require_once("./feed.php");
  createFeed();
} catch (Exception $ex) {
  echo '{"status":"error","message","' . $ex->getMessage()  . '"}';
  exit;
} finally {
  $db->close();
}

//タグクラウド生成
require_once('./make_tagcloud.php');
createTagcloud("{$rel}$system_db_file");

//表示用URL
$url = $PATH_INFO["url_system_root"] . "/view.php?id=$id";


//結果を出力
echo '{"status":"success", "id":' . $id . ', "url":"' . $url . '","image_index":' . $image_idx . '}';
