<?php

/********************************************************************
 * 
 * 記事 削除処理
 * 　　GET : target 削除対象となるLogのID。必須。
 * 
 ********************************************************************/
//クローラー判定
$userAgent = $_SERVER['HTTP_USER_AGENT'];
$isCrawler = preg_match('/bot|crawl|slurp|spider/i', $userAgent);
if ($isCrawler) {
  //とりあえず成功ということにしとく
  echo '{"status":"success"}';
  exit();
}

//共通処理呼び出し
$require_login = false; //ログイン不要
require_once("../common.php");
if (!$SETTING['use_guestwrite']) {
  $db->close();
  showMessage($mode, "error", "ゲスト書き込みが無効になっています");
  exit;
}

$mode = "GET";
$target = filter_input(INPUT_GET, 'target', FILTER_SANITIZE_NUMBER_INT); //処理対象LOG ID
$delete_key = filter_input(INPUT_GET, 'delete_key');
if (!$target) {
  $mode = "POST";
  $target = filter_input(INPUT_POST, 'target', FILTER_SANITIZE_NUMBER_INT); //処理対象LOG ID
  $delete_key = filter_input(INPUT_POST, 'delete_key');
}


if (!$target || !$delete_key) {
  $db->close();
  showMessage($mode, "error", "パラメータが無効です");
  exit;
}

//削除キーを確認
if ($id) {
  $stmt = $db->prepare("select id,delete_key From articles where id=:id and delete_key not null and delete_key != ''");
  $stmt->bindValue(':id',  $id);
  $result = $stmt->execute();
  $row = $result->fetchArray();
  if (!$row || !password_verify($delete_key, $row['delete_key'])) {
    echo '{"status":"error", "msg":"削除キーが無効です"}';
    exit;
  }
}

try {
  $db->exec('begin Immediate');
  //ファイルの削除
  $stmt = $db->prepare('SELECT * FROM images Where article_id= :id');
  $stmt->bindValue(':id', $target);
  $result = $stmt->execute();
  while ($row = $result->fetchArray()) {
    if (file_exists("../images/{$row["file_name"]}")) {
      unlink("../images/{$row["file_name"]}");
    }
    if (file_exists("../images/{$row["thumb_name"]}")) {
      unlink("../images/{$row["thumb_name"]}");
    }
    if (file_exists("../images/{$row["thumb_l_name"]}")) {
      unlink("../images/{$row["thumb_l_name"]}");
    }
  }
  //ログの更新
  $stmt = $db->prepare("delete From articles where id=:id");
  $stmt->bindValue(':id',  $target);
  $result = $stmt->execute();

  $stmt = $db->prepare("delete from images where article_id=:id");
  $stmt->bindValue(':id',  $target);
  $result = $stmt->execute();
  $db->exec('commit;');
} catch (Exception $ex) {
  showMessage($mode, "error", $ex->getMessage());
} finally {
  $db->close();
}
showMessage($mode, "success", "削除しました<br><a href='../index.php'>戻る</a>");

function showMessage($mode, $status, $msg)
{
  if ($mode == "GET") {
    echo $msg;
  } else {
    echo '{"status":"' . $status . '","msg":"' . $msg . '"}';
  }
}
