<?php

/********************************************************************
 * 
 * コンソールページ
 * 
 *  GET q   : 記事絞込用の検索ワード。スペース区切りで複数指定するとAND検索。
 *      page: ページネーション時の表示対象ページ番号。
 * 
 ********************************************************************/

//共通処理呼び出し
$require_login = true; //ログイン必要
require_once("./common.php");
refreshToken("./"); //ログイントークンをリフレッシュ
//キャッシュ無効
header('Cache-Control: no-store, no-cache, must-revalidate');
header('Cache-Control: post-check=0, pre-check=0', FALSE);
header('Pragma:no-cache');

$records_per_page = 30; //1ページ当たりの表示件数

$searchs =  filter_input(INPUT_GET, 'q');
$index =  filter_input(INPUT_GET, 'page', FILTER_VALIDATE_INT);

$limit = $records_per_page;
$offset = 0;
if ($index != "") {
    $offset = ($index - 1)  * $records_per_page;
}

$rowCount = 0;
try {
    // SELECT 文を実行してデータを取得
    if ($searchs == "") {
        $rowCount = $db->querySingle('SELECT Count(id) as count From articles');
        $pages = ceil($rowCount / $records_per_page);

        $result = $db->query('SELECT * From articles ORDER BY created_at DESC LIMIT ' . $records_per_page . ' OFFSET ' . $offset);
    } else {
        //検索条件が指定された場合、SQLでの検索条件式を構築する。
        $search_list = '';
        $search_idx = 0;
        $search_and = '';
        foreach (explode(' ', $searchs) as $search) {
            $search_list = $search_list .  $search_and . "(title like :search{$search_idx} or comment like :search{$search_idx} or tags like :search{$search_idx})";
            $search_and = ' and ';
            $search_idx++;
        }
        $stmt = $db->prepare('SELECT Count(id) as count From articles Where ' . $search_list);

        $search_idx = 0;
        foreach (explode(' ', $searchs) as $search) {
            $stmt->bindValue(":search{$search_idx}",  '%' . $search . '%');
            $search_idx++;
        }
        $result = $stmt->execute();
        $row = $result->fetchArray();
        $rowCount = $row['count'];
        $pages = ceil($rowCount / $records_per_page);

        $stmt = $db->prepare('SELECT *  From articles Where ' . $search_list . ' ORDER BY created_at DESC LIMIT ' . $records_per_page . ' OFFSET ' . $offset);
        $search_idx = 0;
        foreach (explode(' ', $searchs) as $search) {
            $stmt->bindValue(":search{$search_idx}",  '%' . $search . '%');
            $search_idx++;
        }
        $result = $stmt->execute();
    }

    $idx = 0;
    $rowsarray = array();
    $list_html = "";
    while ($row = $result->fetchArray()) {
        $created_at = h($row['created_at']);
        $title = h($row['title']);
        $id = h($row['id']);
        $like = h($row['like']);
        $views = h($row['views']);
        $comment = $row['comment'];
        $pin = $row['pin'] ?? false;
        if ($comment) {
            preg_match('/{caption}(.*?){\/caption}/si', $comment, $match);
            if ($match) {
                //キャプションがある場合はそれを使用
                $comment = $match[1];
            }
            $comment = mb_substr(strip_tags($comment), 0, 100);
            //特殊記述の削除
            $comment = preg_replace('/\{.*\}/', '', $comment);
            $comment = strip_tags($comment);
        }

        $thumbs = $db->query('SELECT id, file_name, thumb_name FROM images where article_id = ' . $id . ' order by sort asc');
        $thumbsarray = array();
        $tidx = 0;
        $trow = $thumbs->fetchArray();
        $item_html = "";
        if ($trow) {
            $file_name =  h($trow['thumb_name']);
            $item_html = "<div class='list-thumb-box' style=\"background-image:url('./images/{$file_name}')\"></div>";
        } else {
            $item_html = "<div class='blank-image'></div>";
        }
        $feedbacks = "";
        if ($SETTING["use_feedback"]) {
            $feedbacks = "<span class='like-it'><i class='fa-regular fa-eye'></i> {$views}</span></span> <span class='nowarp'><span class='like-it'><i id='like_heart' class='fa-regular fa-heart'></i> {$like}</span></span>";
        }
        if ($pin) {
            $feedbacks = $feedbacks . ' <span class="pin"><i class="fa-solid fa-thumbtack"></i></span>';
        }
        $list_html = $list_html . "<li><div class='check_area'><input type='checkbox' class='delete_check' data-id='{$id}'></div>" .
            "<a href='./edit.php?id={$id}'>{$item_html}</a>" .
            "<div class='list-info'><span class='created_at'>{$created_at}</span> <span class='nowarp'>{$feedbacks}<br />" .
            "<a href='./edit.php?id={$id}'><span class='title'>{$title}</span><br /><span class='comment'>{$comment}</span></a></div></li>";
    }
    $db->close();

    $message = "";
    if ($rowCount == "0") {
        if ($searchs == "") {
            $message = "<div id='message'>まだ記事は投稿されていません</div>";
        } else {
            $message = "<div id='message'>「 " . h($searchs) . "」に該当する記事は見つかりません</div>";
        }
    }

    $indexser = "";
    for ($i = 1; $i <= $pages; $i++) {
        if ($i == $index) {
            $indexser = $indexser . $i . ' ';
        } else {
            $indexser = $indexser . '<a href="?page=' . $i . '">' . $i . '</a> ';
        }
    }
} catch (Exception $e) {
    echo $e->getMessage();
}


?>
<!doctype html>
<html lang="ja">

<head>
    <meta charset="utf-8">
    <title>記事管理</title>
    <meta name="description" content="">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="theme-color" content="#fafafa">
    <link rel="stylesheet" href="./style/recss.css">
    <link rel="stylesheet" href="./style/base.css">
    <link rel="icon" href="./resource/icon.png">
    <meta http-equiv="Pragma" content="no-cache">
    <meta http-equiv="Cache-Control" content="no-cache">
    <link rel="stylesheet" href="./style/system.css">
    <style>
        #loglist {
            margin-top: 3em;
            margin-bottom: 3em;
        }

        #loglist li {
            height: 100px;
            overflow: hidden;
            margin-bottom: 5px;
            display: flex;
            flex-direction: row;
        }

        .blank-image {
            float: left;
            height: 100px;
            width: 100px;
            border: 1px solid #999;
            background-color: #eee;
        }

        .blank-image::before {
            content: "NO IMAGE";
            display: inline-block;
            text-align: center;
            line-height: 100px;
            width: 100px;
            color: #ccc;
        }

        .check_area {
            width: 3em;
            margin-right: 2em;
            display: flex;
            justify-content: center;
        }

        input[type="checkbox"].delete_check {
            margin-left: 1em;
            accent-color: var(--warn-d-color);
        }

        .list-thumb-box {
            float: left;
            height: 100px;
            width: 100px;
            background-color: #999;
            border: 1px solid #999;
            overflow: hidden;
            background-size: cover;
            background-position: center center;
        }

        .list-thumb {
            max-height: 200px;
            margin: 0 auto 0 auto;
        }

        .list-info {
            float: left;
            margin-left: 1em;
            overflow: hidden;
            width: calc(90% - 102px);
        }

        #pager {
            margin-top: 2em;
            font-size: 1.5em;
            text-align: center;
        }



        .created_at {
            font-size: 0.8em;
        }

        .like-it {
            font-size: 0.7em;
        }

        .pin {
            font-size: 0.6em;
        }

        .comment {
            font-size: 0.8em;
            max-height: 2em;
            overflow: hidden;
        }

        .comment br {
            display: none;
        }

        .comment br::after {
            content: "  ";
        }

        .title {
            font-weight: 600;
        }

        .nowarp {
            white-space: nowrap
        }

        a {
            color: #777;
            text-decoration: none;
        }

        a:hover {
            color: #999;
            text-decoration: underline;
        }

        #control {
            margin-bottom: 2em;
            display: flex;
            width: 100%;
            flex-direction: row;
            flex-wrap: wrap
        }

        #add-new-button {
            margin-right: 1em;
            height: 2em;
            min-width: 40%;
            margin-bottom: 0.5em;
        }

        #search-area {
            position: relative;
            word-wrap: none;
        }

        #search {
            font-size: 120%;
            border: 1px solid #999;
            border-radius: 20px;
            height: 2em;
            color: #555;
            background-color: #fff;
            padding: 0 2em 0 2em;
            word-wrap: none;
            min-width: 20%;
        }

        #search-button {
            font-size: 130%;
            vertical-align: middle;
            position: absolute;
            display: inline-block;
            height: 1.8em;
            line-height: 1.8em;
            margin-left: 0.5em;
            cursor: pointer;
        }

        #search-clear-button {
            color: rgb(36, 180, 199);
            font-size: 140%;
            vertical-align: middle;
            display: inline-block;
            height: 1.4em;

            position: relative;
            right: 1.6em;

            cursor: pointer;
        }

        .magnifying_glass {
            display: inline-block;
            position: relative;
            width: 1em;
            height: 1em;
            color: #000;
            font-size: 1em;
        }

        .magnifying_glass::before {
            position: absolute;
            top: 0px;
            left: 0px;
            width: 0.7em;
            height: 0.7em;
            box-sizing: border-box;
            border: 0.15em solid currentColor;
            border-radius: 50%;
            background-color: #fff;
            content: "";
        }

        .magnifying_glass::after {
            position: absolute;
            top: 0px;
            left: 50%;
            z-index: -1;
            transform: rotate(-45deg);
            width: 0.15em;
            height: 1em;
            box-sizing: border-box;
            background-color: currentColor;
            content: "";
        }

        #notification {
            cursor: pointer;
        }

        em {
            font-weight: 800;
            font-style: normal;
        }

        #message {
            text-align: center;
        }

        #notification-link {
            color: #888;
        }
    </style>
    <link rel="stylesheet" href="./module/fontawesome/css/all.min.css" rel="preload">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
    <script src="./script/dialog.js?ver=<?= $VERSION ?>"></script>
    <link rel="stylesheet" href="./style/dialog.css">
    <script src="./script/console.js?ver=<?= $VERSION ?>"></script>

</head>

<body>
    <div id="header">
        <a id="back-link" href="./index.php" class="header-link-exit">&lt; TOP</a>
        <div id="header-option-link-area">
            <span id="notification-link" href=""><i id="notification" class="fa-regular fa-bell font-size:1em"></i></span>
            <a id="setting-link" href="./setting.php"><i class="fa-solid fa-gear font-size:1em"></i>設定</a>
            <a id="logout-link" href="./logout.php">ログアウト</a>
        </div>
    </div>
    <div id="base">

        <div id="control">
            <button id="add-new-button" class="button" onClick="location.href='./edit.php';">+<span id="add-new-title_pc"> 記事を作成</span></button>
            <div class="search-input">
                <i id="search-button" onClick="searchExec();" class="fa-solid fa-magnifying-glass"></i>
                <input type="input" id="search" onclick="this.select();" value="<?php echo h($searchs); ?>">
                <i id="search-clear-button" onClick="$('#search').val('')" class="fa-regular fa-circle-xmark"></i>
            </div>
        </div>
        <div id="contents-area">
            <?php echo $message ?>
            <ul id="loglist">
                <?php echo $list_html; ?>
            </ul>
            <div id="control">
                <button id="delete-button" class="button button_warn" onclick="deleteExec();">削除</button>
            </div>
            <div id="pager">
                <?php echo $indexser; ?>
            </div>
        </div>
    </div>



</body>

</html>