<?php

/********************************************************************
 * 
 * 編集ページ
 *    GET   id:編集対象のLOG ID。この値がない場合は新規投稿モード。
 * 
 ********************************************************************/

//共通処理呼び出し
$require_login = false; //ログイン必要
require_once("./common.php");

//ゲスト機能利用チェック
if (!$SETTING['use_guestwrite']) {
  $db->close();
  echo 'ゲスト書き込みが無効になっています';
  exit;
}

//アップロード可能なファイルサイズを得る
$max_send_size = getMaxUploadSize();

//入力値の受け取り
$target = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT); //処理対象LOGID
$delete_key = filter_input(INPUT_GET, 'delete_key', FILTER_SANITIZE_NUMBER_INT);

$mode = "post";
$page_title = "ゲスト記事投稿";
$submit_title = "ゲスト投稿";
$postmode_show = "";
$editmode_show = "hide";
$previews = "";
$guest_attention = $SETTING["guest_attention"] ?? "";

if ($target) {
  //処理対象のLOGIDが指定されている場合は更新モード
  $mode = "edit";
  $postmode_show = "hide";
  $editmode_show = "";
  $page_title = "ゲスト記事更新";
  $submit_title = "ゲスト更新";
}

require_once('./env/tagcloud.php');

if ($mode == "edit") {
  //編集モードのため、対象ログを取得する
  try {
    $stmt = $db->prepare('SELECT * From articles Where id= :id');
    $stmt->bindValue(':id',  $target);
    $result = $stmt->execute();
    if ($row = $result->fetchArray()) {
      $title = h($row['title'] ?? "");
      $comment = h($row['comment'] ?? "");
      $tags = h(trim($row['tags'] ?? ""));
      $created_at = h($row['created_at'] ?? "");
      $pin = $row['pin'] ? "checked" : "";
      $nsfw = $row['nsfw'] ? "checked" : "";
      $hidden = $row['hidden']  ? "checked" : "";
      $views = $row['views'];
      $like = $row['like'];

      $use_html = $row['use_html'] ? "checked" : "";
      $use_full_html = $row['use_full_html'] ? "checked" : "";
      $article_style = $row['style'] ?? 0;

      if (!password_verify($delete_key, $row['delete_key'])) {
        //削除キーが違う
        $db->close();
        echo "削除キーが不正です";
        //header('Location: index.php');
        exit;
      }
    } else {
      //指定されたログが存在しない
      $db->close();
      header('Location: index.php');
      exit;
    }

    //画像一覧構築
    $stmt = $db->prepare('SELECT id, article_id, file_name, sort FROM images Where article_id= :id Order by sort ASC');
    $stmt->bindValue(':id',  $target);
    $result = $stmt->execute();
    while ($row = $result->fetchArray()) {
      $d = "'";
      $previews = $previews . '<li class="preview-item" data-filename="' . h($row["file_name"])  .  '"><img id="preview-' . h($row["file_name"])  . '" src="./images/' . h($row["file_name"])  . '" >' .
        '<button type="button" onClick="$(this).parent().remove();addRemoveImageList(' . $d . $row["id"] . $d . ')">×</button><i class="fa-regular fa-circle-right mover" style="display:none"></i><i class="fa-regular fa-circle-left movel"  style="display:none"></i></li>';
    }
  } catch (Exception $ex) {
    echo "システムエラーが発生しました";
    exit;
  } finally {
    $db->close();
  }
} else {
  //新規モードのため全て空にする
  $title = "";
  $comment = "";
  $tags = "";
  $use_html = "";
  $use_full_html = "";
  $nsfw = "";
  $pin = "";
  $hidden = "";
  $views = "-";
  $like = "-";
  $delete_key = "";
  $article_style = 0;
  date_default_timezone_set('Asia/Tokyo'); // タイムゾーンを設定
  $created_at = date('Y-m-d H:i:s'); // 日時をフォーマット
}
?>

<!doctype html>
<html lang="ja">

<head>
  <meta charset="utf-8">

  <meta http-equiv="Pragma" content="no-cache">
  <meta http-equiv="Cache-Control" content="no-cache">

  <title><?= $page_title ?></title>
  <meta name="description" content="">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="theme-color" content="#fafafa">
  <link rel="stylesheet" href="./style/recss.css">
  <link rel="stylesheet" href="./style/base.css">
  <link rel="stylesheet" href="./style/system.css">
  <link rel="stylesheet" href="./style/edit.css">
  <link rel="stylesheet" href="https://ajax.googleapis.com/ajax/libs/jqueryui/1.13.2/themes/smoothness/jquery-ui.css">
  <link rel="stylesheet" href="./module/fontawesome/css/all.min.css" rel="preload">
  <link rel="icon" href="./resource/icon.png">
  <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>
  <script src="https://ajax.googleapis.com/ajax/libs/jqueryui/1.13.2/jquery-ui.min.js"></script>
  <script src="./script/edit.js?ver=<?= $VERSION ?>"></script>
  <script>
    //クライアントリサイズのボーダーを設定
    max_size = <?= $SETTING['resize_border'] ?>;
    guest_mode = true;
  </script>

  <script src="./script/dialog.js?ver=<?= $VERSION ?>"></script>
  <link rel="stylesheet" href="./style/dialog.css">
  <script src="./script/tooltip.js?ver=<?= $VERSION ?>"></script>
</head>

<body>
  <div id="header">
    <a id="back-link" href="./index.php" class="header-link-exit">
      &lt; 戻る
    </a>
    <div id="header-option-link-area">
      <?php if ($mode == "edit") { ?>
        <a id="view-link" href="./view.php?id=<?= $target ?>">閲覧ページを開く</a>
      <?php } ?>
    </div>
  </div>
  <div id="base">
    <div id="contents-area">
      <div style="margin-bottom:1em"><?= $guest_attention ?></div>
      <form action="guest_post.php" method="post" enctype="multipart/form-data" id="inputForm">
        <input type="file" name="tmp" id="fileSelect" accept="image/*" multiple class="hide" data-maxsize="<?= $max_send_size ?>">
        <input type="text" name="id" id="id" class="hide" value="<?= $target; ?>">
        <input type="text" name="color" id="color" class="hide" value="<?= $color; ?>">
        <input type="text" name="removeimages" class="hide" id="removeimages">
        <input type="text" name="sort" class="hide" id="sort">
        <div>
          <div id="dropArea" class="dropArea <?= $postmode_show ?>">
            <span style="display:inline-block;margin-top:14%"> 画像ファイルをドラッグ<br />または<br />タップで画像を選択</span>
          </div>
          <div id="previewArea" class="<?= $editmode_show ?>">
            <ul id="previewList">
              <?= ($previews) ?>
              <li id="dropArea2Root">
                <div id="dropArea2" class="dropArea">
                  <span style="display:inline-block;margin-top:14%"> 画像ファイルをドラッグ<br />または<br />タップで画像を選択</span>
                </div>
              </li>
            </ul>
          </div>
        </div>
        <div class="view-info-area"><?php if ($SETTING['use_feedback']) { ?><span class='like-it'><i class='fa-regular fa-eye'></i> <?= $views ?> <i id='like_heart' class='fa-regular fa-heart'></i> <?= $like ?></span><?php } ?></div>
        <div class="input-area" id="input-area" class="flat-input__noborder">
          <input type="text" id="created_at" name="created_at" value="<?= $created_at ?>" placeholder="作成日時"><br>
          <input type="text" id="title" name="title" value="<?= $title ?>" placeholder="タイトル"><!-- <i class="fa-solid fa-palette" style="position:absolute;margin-left:-1.5em;color:#999"></i>-->
          <hr />
          <textarea name="comment" id="comment" class="flat-input__noborder" placeholder="コメント"><?= $comment ?></textarea>
        </div>
        <div style="margin-top:0.5em">
          スタイル：
          <select id="combobox" name="style" class="flat-input">
            <option value="0" <?php echo $article_style == 0 ? "selected" : "" ?>>シンプル</option>
            <option value="1" <?php echo $article_style == 1 ? "selected" : "" ?>>詳細記事</option>
          </select>
          <a href="https://ppp.kannagi.net/view.php?id=2" style="font-weight:100; font-size:0.9em;" target="_blank">[ヘルプ]</a>
        </div>

        <div class="input-area" id="tag-input-area">
          <input type="text" id="tags" name="tags" value="<?= $tags; ?>" placeholder="タグ">
        </div>
        <span style="font-size:0.8em;color:#555">タグはスペース区切りで入力してください。タグそのものにスペースは使用できません。</span>
        <div id="tagcloud">
          <?= $tagcloud_nolink ?>
          <?= $tagcloud_nolink_more ?>
        </div>
        <div id="options-area">
          <input type="checkbox" name="nsfw" id="nsfw" <?= $nsfw ?>><label for="nsfw">NSFW(R18)</label><br><br>
          削除キー: <input class="input-area" type="text" id="delete_key" name="delete_key" value="<?= $delete_key; ?>" placeholder="削除キー">
        </div>
        <div id="submit-area">
          <button id="submit" name="submit" class="button button_submit"><?= $submit_title ?></button>
        </div>
      </form>
      <?php if ($mode == "edit") { ?>
        <div id="delete-area">
          <button id="delete" class="button button_warn" data-target="<?= $target ?>">削除</button>
        </div>

      <?php } ?>
    </div>
    <footer id="footer-area">
    </footer>
  </div>
  <span style="display:none" class="sitetitle"><?= $SETTING["site_title"] ?></span>
  <script>
    $mode = '<?= $mode ?>';
    $tweetmode = '<?php echo $SETTING["tweet_service_key"] ? "api" : "normal" ?>';
  </script>
</body>

</html>