<?php

/********************************************************************
 * 
 * トップページ
 *    GET   q   :  検索ワード。スペース区切りで複数指定するとAND検索。
 *    GET   page:  ページネーションインデックス。
 * 
 ********************************************************************/
ini_set('display_errors', "On");
//共通処理呼び出し
$require_login = false; //ログイン不要
require_once("./common.php");

//入力値の受け取り
$searchs =  filter_input(INPUT_GET, 'q');
$index =  filter_input(INPUT_GET, 'page', FILTER_VALIDATE_INT) ?? 1;
$static_mode = filter_input(INPUT_GET, 'static_mode', FILTER_SANITIZE_NUMBER_INT) ?? 0; //静的出力モード

//1ページ当たり記事数
$records_per_page = $SETTING["index_articles"] ?? 28;
$limit = $records_per_page;
$offset = 0;
if ($index) {
    $offset = ($index - 1)  * $records_per_page;
}

try {
    //アカウント設定の読み取り
    $account_rows = $db->query('SELECT * FROM accounts');
    while ($row = $account_rows->fetchArray()) {
        $accounts[] = $row;
    }

    //メニュー読み取り
    $home_menu = "";
    $result = $db->query('SELECT id, created_at, title, comment, tags, nsfw From articles' .
        ' Where style=99 ORDER BY created_at DESC');
    while ($row = $result->fetchArray()) {
        $home_menu = $home_menu . "<li  class='home_menu_item' data-id='{$row['id']}'>{$row['title']}</li>";
    }
    if ($home_menu != "") {
        $home_menu = '<ul class="home_menu"><li class="home_menu_item home_menu_item_current">HOME</li>' . $home_menu . '</ul>';
    }

    //非表示タグ一覧
    $exclude_index_list_tag = '';
    if ($SETTING['exclude_index_list_tag']) {
        foreach (explode(' ', $SETTING['exclude_index_list_tag']) as $tag) {
            $exclude_index_list_tag = $exclude_index_list_tag .  " and tags not like '%" . h($tag) . "%'";
        }
    }

    //記事一覧生成
    $article_count = 0;
    if ($searchs == '') {
        //検索なし
        //hidden指定されていない記事を$records_per_page分取得する
        $article_count = $db->querySingle('SELECT Count(id) as count From articles WHERE hidden != 1 ' . $exclude_index_list_tag);
        $pages = ceil($article_count / $records_per_page);

        $result = $db->query('SELECT id, created_at, title, comment, tags, nsfw From articles' .
            ' Where hidden != 1 ' . $exclude_index_list_tag . 'ORDER BY PIN Desc,created_at DESC LIMIT ' .
            $records_per_page . ' OFFSET ' . $offset);
    } else {
        //検索条件あり
        //検索条件に従って記事を検索する。スペース区切りで複数指定があった場合はAND条件とする。
        //検索条件式の構築
        $search_list = '';
        foreach (explode(' ', $searchs) as $search_Idx => $search) {
            $search_list = $search_list .  " and (title like :search{$search_Idx} or comment like :search{$search_Idx} or tags like :search{$search_Idx})";
        }
        //検索結果数の取得
        $stmt = $db->prepare('SELECT Count(id) as count From articles WHERE hidden != 1 AND ' . $search_list . ' ' . $exclude_index_list_tag);
        foreach (explode(' ', $searchs) as $search_Idx => $search) {
            $stmt->bindValue(":search{$search_Idx}",  '%' . $search . '%');
        }
        $result = $stmt->execute();
        $row = $result->fetchArray(); //結果は常に1行
        $article_count = $row['count'];
        $pages = ceil($article_count / $records_per_page);

        //記事の取得
        $stmt = $db->prepare('SELECT id, created_at, title, comment, tags, nsfw From articles WHERE hidden != 1 ' . $search_list .  ' ' . $exclude_index_list_tag .
            ' ORDER BY pin DESC, created_at DESC LIMIT ' . $records_per_page . ' OFFSET ' . $offset);
        foreach (explode(' ', $searchs) as $search => $search_Idx) {
            $stmt->bindValue(":search{$search_Idx}",  '%' . $search . '%');
        }
        $result = $stmt->execute();
    }

    //記事一覧の生成 ( $articles )
    $idx = 0;
    $list = '';
    $articles = array();

    while ($row = $result->fetchArray()) {
        $articles[$idx]['created_at'] = h($row['created_at']);
        $articles[$idx]['title'] = $row['title'];
        $article_id = h($row['id']);
        $articles[$idx]['id'] = h($row['id']);
        $articles[$idx]['nsfw'] = h($row['nsfw']);
        $articles[$idx]['comment'] = mb_substr(strip_tags($row['comment']), 0, 100);

        //記事に画像添付があるか確認
        $thumbs = $db->query('SELECT id, file_name FROM images WHERE article_id = ' . $article_id . ' ORDER BY sort ASC');
        $trow = $thumbs->fetchArray(); //最初の1件を取得
        if ($trow) {
            //サムネイルは拡張子jpg
            $articles[$idx]['image'] = preg_replace('/\.(gif|png|mp4|webm|webp)/i', '.jpg', h($trow['file_name']));
            $trow = $thumbs->fetchArray(); //次の一件を取得
            if ($trow) {
                $articles[$idx]['multi_image'] = 1;
            } else {
                $articles[$idx]['multi_image'] = 0;
            }
        } else {
            //画像なし
            $articles[$idx]['image'] = "";
        }
        $idx++;
    }

    $owner_control = "";

    //最新記事情報の取り出し
    $first_article_comment = "";
    $first_article_title = "";
    $first_article_image = "";
    $first_article_image_s = "";
    $first_article_id = "";
    $result = $db->query('SELECT id, created_at, title, comment, tags, nsfw From articles' .
        ' Where hidden != 1 ORDER BY created_at DESC LIMIT 1');
    if ($row = $result->fetchArray()) {
        $first_article_comment = mb_substr(strip_tags($row['comment']), 0, 300);
        $first_article_title = h($row['title']);
        $first_article_id =  h($row['id']);
        //記事に画像添付があるか確認
        $thumbs = $db->query('SELECT * FROM images WHERE article_id = ' . $first_article_id . ' ORDER BY sort ASC');
        $trow = $thumbs->fetchArray(); //最初の1件を取得
        if ($trow) {
            //画像ありの記事
            if (!$SETTING["nsfw"] && $row['nsfw'] && !$NSFW_CONSENT) {
                //NSFW確認が取れていない
                $first_article_image = "./resource/nsfw.png";
                $first_article_image = '<a href="./view.php?id=' . $article_id . '"><img class="instraction-image" src="./resource/nsfw.png"></a>';
                $first_article_image_s = '<a href="./view.php?id=' . $article_id . '"><img class="instraction-image" src="./resource/nsfw.png"></a>';
            } else {
                //サムネイルは拡張子jpg
                $first_article_image  = h($trow['thumb_l_name']);

                $first_article_image_html = '<a href="./view.php?id=' . $first_article_id . '"><img class="instraction-image" src="./images/' . $first_article_image . '" width=' . h($trow['thumb_l_width']) . ' height=' . h($trow['thumb_l_height']) . '></a>';
                $first_article_image_s_html = '<a href="./view.php?id=' . $first_article_id . '"><img class="instraction-image" src="./images/' .  h($trow['thumb_name']) . '" width=' . h($trow['thumb_width']) . ' height=' . h($trow['thumb_height']) . '></a>';
            }
        } else {
            //画像なしの記事
            $first_article_image = "";
        }
    }

    //タグクラウド用データ読み取り
    require_once('./env/tagcloud.php');

    //その他本文用データ構築 ( $document )

    //サイト説明文内の特殊構文を変換
    $instruction_text = $SETTING["instruction_text"];
    if ($first_article_image != "") {
        $instruction_text = preg_replace('/{new-thumb}/i', $first_article_image_html, $instruction_text);
        $instruction_text = preg_replace('/{new-thumb-s}/i', $first_article_image_s_html, $instruction_text);
    } else {
        $instruction_text = preg_replace('/{new-thumb}/i', '', $instruction_text);
        $instruction_text = preg_replace('/{new-thumb-s}/i', '', $instruction_text);
    }
    $instruction_text = preg_replace('/{new-title}/i', $first_article_title, $instruction_text);
    $instruction_text = preg_replace('/{new-comment}/i', $first_article_comment, $instruction_text);
    $instruction_text = preg_replace('/{(\d+)\-(\d+)}/i', "<img class='instraction-image' src='./images/thumb_l_image_$1_$2.jpg'>", $instruction_text);
    $instruction_text = preg_replace('/{(\d+)\-(\d+) s}/i', "<img class='instraction-image' src='./images/thumb_image_$1_$2.jpg'>", $instruction_text);
    $instruction_text = preg_replace('/{search:(.*?)}/i', '<a href="./list.php?q=$1">$1</a>', $instruction_text);
    $instruction_text = preg_replace('/{tag:(.*?)}/i', '<a href="./list.php?q=$1" class="tag">#$1</a>', $instruction_text);
    $instruction_text = preg_replace('/{link:(.*?) (.*?)}/i', '<a href="./view.php?id=$1">$2</a>', $instruction_text);

    $document = array();
    $document['nsfw_consent'] = $NSFW_CONSENT;
    $document['max_index'] = $pages;
    $document['min_index'] = 1;
    $document['current_index'] = $index;
    $document['article_count'] = $article_count;
    $document['search_words'] = $searchs;
    if ($SETTING['use_tag_cloud']) {
        $document['tag_cloud'] = $tagcloud_links . $tagcloud_links_more;
    } else {
        $document['tag_cloud'] = "";
    }
    $document['instruction_text'] = $instruction_text;

    //Twitterカード用データ
    $document['card_title'] = $SETTING['site_title'];
    $document['card_comment'] = $SETTING['twitter_card_text'];
    $document['card_thumbnail'] = $PATH_INFO['url_system_root'] . '/images/banner.jpg';
    $document['card_ogimage']    = $PATH_INFO['url_system_root'] . '/images/ogimage.jpg';
} catch (Exception $ex) {
    echo ("システムエラーが発生しました" . $ex->getMessage());
    exit;
} finally {
    $db->close();
}
//UIレンダリング
require_once('./module/NoSixTemplate.php');
if (file_exists('./env/templates/template_index.php')) {
    //ユーザーテンプレートがある場合はそちらを採用する
    $template = new NoSixTemplate('template_index.php', './env/templates/');
} else {
    $template = new NoSixTemplate('template_index.php', './templates');
}
$template->set_data('setting', $SETTING); //Array
$template->set_data('accounts', $accounts); //Array[](url, icon)
$template->set_data('articles', $articles); //Array[](id,title,created_at,comment,image)
$template->set_data('home_menu', $home_menu);
$template->set_data('document', $document); //Array(max_index,min_index,current_index,article_count,search_words)
$template->set_data('login', $LOGIN); //ログイン有無
$template->set_Data('static_mode', $static_mode);
$template->set_Data('VERSION', $VERSION);

if ($static_mode == 1) {
    //静出力モード
    $file_name = "./index.html";
    ob_start();

    $template->display();

    $output = ob_get_contents();
    ob_end_clean();
    file_put_contents($file_name, $output);
    echo ('{"state":"success", "path", "' . $file_name . '"}');
    exit;
}


$template->display();
