<?php

/************************************************************************************** 
 * initialize.php
 * 本システム利用開始時の初期化処理を行います
 *
 * env ディレクトリ内の「system_setting.php」「user_setting.php」の存在を確認して
 * 処理モードが変更されます。
 *
 *「system_setting.php」が存在しない場合：完全初期化モード
 *「user_setting.php」が存在しない場合  ：ユーザーID・パスワード変更モード
 *
 ***************************************************************************************/

ini_set('display_errors', "Off");

$SYSTEM_SETTING_FILE = './env/system_setting.php';
$USER_SETTING_FILE = './env/user_setting.php';

$DEMO_USER = "";
$DEMO_PASSWORD = "";

$message = "";
/*
if (empty($_SERVER['HTTPS']) && !strstr($_SERVER['HTTP_HOST'], "127.0.0.1") && !strstr($_SERVER['HTTP_HOST'], "192.168.")) {
    echo "HTTPSでアクセスしてください";
    exit;
}*/


if (file_exists($SYSTEM_SETTING_FILE) && file_exists($USER_SETTING_FILE)) {
    //設定ファイルが両方ある場合は初期化済み
    echo "初期化済みです";
    return;
} else if (file_exists($SYSTEM_SETTING_FILE) && !file_exists($USER_SETTING_FILE)) {
    //ユーザー / パスワード変更モード
    $message = '<span style="color:red">ユーザーID・パスワードを再設定します</span><br>';
    $next_step = "user_initialize";
} else {
    $message = '<img src="./resource/initlogo.png"><br>Simple Blog System PictPostPersonalへようこそ。<br>最初にユーザーIDとパスワードを設定します。<br>';
    $next_step = "all_initialize";
}

// stepなし：操作画面表示 stepあり:stepに応じた処理実行
$step = filter_input(INPUT_POST, 'step');

if ($step) {

    if ($step === "user_initialize" || $step === "all_initialize") {
        //フォルダ作成
        if (!file_exists("./env")) {
            mkdir("./env/", 0755);
            $fp = fopen("./env/index.html", "w");
            fclose($fp);
        }
        if (!file_exists("./images")) {
            mkdir("./images/", 0755);
            $fp = fopen("./images/index.html", "w");
            fclose($fp);
        }
        if (!file_exists("./images/upd")) {
            mkdir("./images/upd", 0755);
            $fp = fopen("./images/upd/index.html", "w");
            fclose($fp);
        }

        //ユーザーID・パスワードの初期化
        $username = filter_input(INPUT_POST, 'username');
        $password = filter_input(INPUT_POST, 'password');
        $re_password = filter_input(INPUT_POST, 're_password');
        if ($password != $re_password || $username == "") {
            echo ("設定値が不正です");
            exit;
        }

        //パスワード設定
        $fp = fopen($USER_SETTING_FILE, "w");
        fwrite($fp, "<?php\n");
        fwrite($fp, '$sys_username="' .  preg_replace('/[\'"$]/', '\\\\$0', $username) . '";' . "\r\n");
        fwrite($fp, '$sys_password="' .   preg_replace('/[\'"$]/', '\\\\$0', password_hash($password, PASSWORD_DEFAULT)) . '";' . "\r\n");
        fclose($fp);

        //ログイン状態にする
        require_once("./token.php");
        publishToken("./", $username);
    }

    if ($step === "all_initialize") {
        //データベースの初期化
        $db_file_path = filter_input(INPUT_POST, 'dbfilepath');
        if (!$db_file_path) {
            // 指定がない場合はランダムなファイル名を生成
            $db_file_path = './env/' . bin2hex(random_bytes(rand(15, 20))) . '.db';
        }

        //DB構築
        $db = new SQLite3($db_file_path);
        $db->enableExceptions(true); //例外発生をONに設定
        $db->busyTimeout(5000); //ビジーハンドルを5秒に設定
        $retry = 0;
        while ($retry < 10) {
            try {
                $db->exec('PRAGMA journal_mode=wal');
                $retry = 99;
            } catch (Exception $ex) {
                sleep(1000);
                $retry++;
            }
        }
        if ($retry != 99) {
            echo "失敗";
            $db->close();
            exit;
        }

        $db->exec('begin Immediate');
        $db->exec("
        CREATE TABLE [accounts] (
            [id] INTEGER PRIMARY KEY AUTOINCREMENT,
            [url] TEXT,
            [icon] TEXT
            );

            INSERT INTO [accounts] ([id],[url],[icon]) VALUES ('1','','');
            INSERT INTO [accounts] ([id],[url],[icon]) VALUES ('2','','');
            INSERT INTO [accounts] ([id],[url],[icon]) VALUES ('3','','');
            INSERT INTO [accounts] ([id],[url],[icon]) VALUES ('4','','');
            INSERT INTO [accounts] ([id],[url],[icon]) VALUES ('5','','');
        ");

        $db->exec("
            CREATE TABLE [images] (
            [id]	INTEGER,
            [article_id]	INTEGER,
            [image_id] INTEGER,
            [sort]	INTEGER,
            [file_name]	TEXT,
            [width] INTEGER,
            [height] INTEGER,
            [thumb_l_name] TEXT,
            [thumb_l_width] INTEGER,
            [thumb_l_height] INTEGER,
            [thumb_name] TEXT,
            [thumb_width] INTEGER,
            [thumb_height] INTEGER,
            [type] TEXT DEFAULT 'image',
            PRIMARY KEY([id] AUTOINCREMENT)
        );
        create index articles_article_id on images(article_id);
        ");

        $db->exec("
            CREATE TABLE [articles] (
            [id] INTEGER PRIMARY KEY AUTOINCREMENT,
            [hidden] BOOLEAN,
            [created_at] DATETIME,
            [title] TEXT,
            [comment] TEXT,
            [tags] TEXT,
            [color] TEXT,
            [use_html] BOOLEAN DEFAULT '0',
            [use_full_html] BOOLEAN DEFAULT '0',
            [style] INTEGERT DEFAULT '0',
            [pin] BOOLEAN DEFAULT '0',
            [nsfw] BOOLEAN DEFAULT '0',
            [like] INTEGER DEFAULT '0',
            [views] INTEGER DEFAULT '0',
            [from_ip] TEXT,
            [delete_key] TEXT
            );
        ");

        $db->exec("
        CREATE TABLE [setting] (
            [id] INTEGER,
            [site_title] TEXT,
            [display_name] TEXT,
            [mail_address] TEXT DEFAULT '',
            [thumbnail_type] INTEGER,
            [instruction_text] TEXT,
            [instruction_text_use_html]  DEFAULT '0',
            [twitter_card_text] TEXT,
            [nsfw]  DEFAULT '0',
            [show_title] BOOLEAN '0',
            [use_icon] BOOLEAN DEFAULT '0',
            [use_banner] BOOLEAN DEFAULT '0',
            [use_favicon] BOOLEAN DEFAULT '0',
            [use_ogimage] BOOLEAN DEFAULT '0',
            [image_color] TEXT,
            [use_static_generation]  DEFAULT '0',
            [static_index_file_path] TEXT,
            [static_log_file_dir] TEXT,
            [use_tag_cloud] BOOLEAN DEFAULT '1',
            [index_articles] INTEGER,
            [tweet_service] TEXT,
            [tweet_service_key] TEXT,
            [use_feedback] BOOLEAN DEFAULT '1',
            [show_likes] BOOLEAN DEFAULT '0',
            [move_link_type] INTEGER DEFAULT '1',
            [use_comment] BOOLEAN DEFAULT '0',
            [resize_border] INTEGER DEFAULT '1980',
            [exclude_index_list_tag] TEXT,
            [use_guestwrite] BOOLEAN DEFAULT '0',
            [guest_attention] TEXT DEFAULT '',
            [use_portal_feed] BOOLEAN DEFAULT '0',
            [portal_feed_urls] TEXT,
            [portal_tags] TEXT DEFAULT '',
            [portal_post_tags] TEXT DEFAULT '',
            [exclude_portal_post_tags] TEXT DEFAULT '',
            [use_mini_banner] BOOLEAN DEFAULT '0',
            PRIMARY KEY([id])
            );
            INSERT INTO [setting] ([id],[site_title],[display_name],[thumbnail_type],[instruction_text],[instruction_text_use_html],[twitter_card_text],[use_icon],[use_banner],[use_favicon],[image_color],[use_tag_cloud],[index_articles],[tweet_service])
            VALUES ('1','タイトル','@user_name',NULL,'','0','','0',NULL,'0','#51bb9b','1', 28,'https://ppp.kannagi.net/tweet/');
        ");

        $db->exec("
        CREATE TABLE [activity] (
            [id] INTEGER PRIMARY KEY AUTOINCREMENT,
            [target] INTEGER,
            [created_at] DATETIME,
            [from_ip] TEXT,
            [action] TEXT,
            [read] BOOLEAN DEFAULT '0'
            );
        ");

        $db->exec("
        CREATE TABLE [templates] (
            [id] INTEGER PRIMARY KEY AUTOINCREMENT,
            [template_name] TEXT,
            [template_sort] INTEGER DEFAULT '10',
            [value] TEXT,
            [option1] TEXT,
            [option2] TEXT,
            [option3] TEXT,
            [option4] TEXT,
            [option5] TEXT
            );
        ");

        $db->exec("
        CREATE TABLE [comments] (
            [id] INTEGER PRIMARY KEY AUTOINCREMENT,
            [target] INTEGER,
            [from_owner] BOOLEAN,
            [replay_to_id] INTEGER,
            [created_at] DATETIME,
            [from_ip] TEXT,
            [sender_name] TEXT,
            [sender_address] TEXT,
            [message] TEXT
            );
        ");

        $db->exec('commit');
        $db->close();

        //設定ファイルにDBへのパスを記録
        $fp = fopen($SYSTEM_SETTING_FILE, "w");
        fwrite($fp, "<?php\n");
        fwrite($fp, '$system_db_file="' . $db_file_path . '";' . "\r\n");
        fclose($fp);

        //タグクラウドファイル生成
        $fp = fopen("./env/tagcloud.php", "w");
        fwrite($fp, "<?php\n");
        fwrite($fp, '$tagcloud_links = "";' . "\n");
        fwrite($fp, '$tagcloud_nolink = "";');
        fwrite($fp, '$tagcloud_links_more = "";' . "\n");
        fwrite($fp, '$tagcloud_nolink_more = "";');
        fwrite($fp, '$tagcloud_list = "";');
        fclose($fp);
    }

    //USER CSSの初期化
    if (!file_exists("./env/user.css")) {
        copy("./resource/default_user.css", "./env/user.css");
    }

    header('Location: setting.php');
    exit;
}
?>

<!doctype html>
<html lang="ja">

<head>
    <meta charset="utf-8">
    <title>初期設定</title>
    <meta name="description" content="">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="theme-color" content="#fafafa">
    <link rel="stylesheet" href="./style/recss.css">
    <link rel="stylesheet" href="./style/base.css">
    <link rel="stylesheet" href="./module/fontawesome/css/all.min.css" rel="preload">

    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.3.1/jquery.min.js"></script>

    <script src="./script/dialog.js?ver=<?= $VERSION ?>"></script>
    <link rel="stylesheet" href="./style/dialog.css">

    <style>
        #container {
            display: flex;
            justify-content: center;
            align-items: center;

            width: 100%;
            height: 100vh;
        }

        #login-button {
            display: block;
            margin: 3em auto 0 auto;
        }

        table {
            margin: 0 auto 0 auto;
        }

        tr {
            height: 2.5em;
        }

        td {
            width: 15em;
        }

        #message {
            width: 100%;
            display: block;
            color: #f00;
            font-size: 0.9em;
            text-align: center;
            margin: 2em auto 2em auto;

        }

        label {
            margin-right: 3em;
        }

        .wmessage {
            color: red;
        }
    </style>
    <script>
        $(async function() {

            $('#password').on('input', function() {
                passwordCheck();
            });
            $('#re-password').on('input', function() {
                passwordCheck();
            });


            $('form').on('submit', async function(e) {
                if (!passwordCheck()) {
                    e.preventDefault();
                    await $("body").showDialog("ID/パスワードを確認してください");
                    return;
                }
                var wait = $('body').waitDialog("処理中…");
            });
        });

        function passwordCheck() {
            var err = false;
            var password = $("#password").val();
            var repassword = $("#re-password").val();
            var hasUpperCase = /[A-Z]/.test(password);
            var hasLowerCase = /[a-z]/.test(password);
            var hasNumbers = /\d/.test(password);
            if (password.length < 8) {
                $('#password-strength').html('パスワードは8文字以上である必要があります。');
                err = true;
            } else if (!hasUpperCase || !hasLowerCase || !hasNumbers) {
                $('#password-strength').html('パスワードには大文字・小文字・数字を含めてください。');
                err = true;
            } else if (password != repassword) {
                $('#password-strength').html("パスワードと再入力の内容が異なります");
                err = true;
            } else if ($("#username").val() == "") {
                $('#password-strength').html("ユーザーIDを入力してください");
            } else {
                $('#password-strength').html("");
            }

            if (err ||
                $("#username").val() == "" ||
                password == "" ||
                password != repassword) {
                return false;
            }
            return true;
        }
    </script>

</head>

<body>
    <div id="container">

        <div class="login-area">
            <?php echo $message ?>
            <div style="text-align:center">
                <?php
                if (empty($_SERVER['HTTPS'])) {
                    $protocol = "https";
                    $host = $_SERVER['HTTP_HOST'];
                    $url = $protocol . "://" . $host . $_SERVER['REQUEST_URI'];
                    echo '<span style="color:#f00">セキュリティ強化のため、HTTPSでのアクセスを推奨しています</span><br>';
                    echo '<a href="' . $url . '">[HTTPSに変更]</a>';
                }
                ?>
            </div>
            <br>
            <form action="./initialize.php" method="POST">
                <table>
                    <tr>
                        <td><label for="username">ユーザーID</label></td>
                        <td><input type="text" id="username" name="username" class="flat-input" value="<?= $DEMO_USER ?>"></td>
                    </tr>
                    <tr>
                        <td><label for="password">新しいパスワード</label></td>
                        <td><input type="password" id="password" name="password" class="flat-input" value="<?= $DEMO_PASSWORD ?>"></td>
                    </tr>
                    <tr>
                        <td><label for="password">新しいパスワード(再入力)</label></td>
                        <td><input type="password" id="re-password" name="re_password" class="flat-input" value="<?= $DEMO_PASSWORD ?>"></td>
                    </tr>
                </table>
                <span id="password-strength" class="wmessage"></span><br>
                ※パスワードは8文字以上・大文字・小文字・数字を含めてください。<br><br>
                <span style="font-size:0.9em; color:#449944;cursor:pointer" onClick="$('#options').toggle()">オプション設定▼</span>
                <div class="hide" id="options">
                    <table>
                        <tr>
                            <td>DBファイルパス</td>
                            <td><input type="text" id="dbfilepath" name="dbfilepath" class="flat-input" placeholder="通常は空で問題ありません"></td>
                        </tr>
                    </table>
                </div>
                <input type="hidden" name="step" value="<?php echo $next_step; ?>">
                <button name="submit" value="決定" class="button" id="login-button">決定</button>
            </form>
        </div>

</body>

</html>