<?php

/****************************************************************
 * 
 * 個別記事表示ページ
 * 　_GET
 *     *id  数値。表示する記事のID。必須。
 *     *cachemode 1だと静的出力モード。 log_{id}.htmlを吐き出す。
 * 
 *****************************************************************/
//共通処理呼び出し
$require_login = false; //ログイン不要
require_once("./common.php");

//引数読み込み
$target = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT); //処理対象Logs-ID
if ($target == "") {
  //ID指定がない場合はトップページに戻る
  header("Location: index.php");
  exit;
}
$static_mode = filter_input(INPUT_GET, 'static_mode', FILTER_SANITIZE_NUMBER_INT) ?? 0; //静的出力モード
$index =  filter_input(INPUT_GET, 'page', FILTER_VALIDATE_INT) ?? 1;

//logsテーブルから記事を検索
try {
  $stmt = $db->prepare('SELECT * From articles Where id= :id');
  $stmt->bindValue(':id',  $target);
  $result = $stmt->execute();
  if (!$row = $result->fetchArray()) {
    //指定されたログが存在しない
    $db->close();
    header("Location: index.php");
    exit;
  }
} catch (Exception $ex) {
  $db->close();
  echo 'システムエラーが発生しました<br>';
  $error = $ex->getTraceAsString();
  exit;
}

//NSFW確認
$nsfw = $row['nsfw'] ?? false;
if ($nsfw && $NSFW_CONSENT == "0") {
  $db->close();

  //NSFWコンテンツだが同意がとれていない
  header("Location: nsfw.php?title=" . h($row['title']) . "&request=" . $target);
  exit;
}

$article = array();
$article['id'] = $target;
$article['nsfw'] = false;
$article['title'] = $row['title'];
$article['created_at'] =  h($row['created_at']);
$article['views'] = $row['views'];
$article['like'] = $row['like'];

if (strstr($article['created_at'], "9999")) {
  $article['created_at'] = "";
}

//コメント
$comment = $row['comment'] ?? "";
if (!$row['use_html']) {
  //通常モード = タグをエスケープする
  $comment = h($comment);
}

//キャプションを取り出し
$caption = "";
$comment = preg_replace('/{\/caption}\r\n/i', '{/caption}', $comment);
$comment = preg_replace('/{\/caption}\n/i', '{/caption}', $comment);
preg_match('/{caption}(.*?){\/caption}/si', $comment, $match);
if ($match) {
  $caption = $match[1];
  $caption = convertLineBreaks($caption);
  $comment = preg_replace('/{caption}(.*?){\/caption}\r?\n?/si', '', $comment);
}

//タグクラウド
$primary_tag = "";
$tags = "";
$tags_raw = array();
foreach (explode(' ', $row['tags']) as $tag) {
  if ($tag != "") {
    if (substr($tag, 0, 1) == "-") {
      continue;
      //$tag = substr($tag, 1);
    }
    $tags = $tags . "<a href='./list.php?q={$tag}'>#{$tag}</a> ";
    $tags_raw[] = $tag;
    if ($primary_tag == "") {
      //プライマリタグ
      $primary_tag = $tag;
    }
  }
}
$article["tags"] = $tags;

$advance_mode = $row['use_full_html'] ?? false; //画像もHTML内で指定する
$style = $row['style'];
if ($row['delete_key'] && $row['delete_key'] != "") {
  $delete_link = '<form id="guest_delete_form" action="./api/guest_delete.php" method="GET">削除キー：<input type="hidden" name="target" value="' . $target . '"><input class="flat-input" style="width:5em" type="password" name="delete_key"><button style="background-color:#CCC;margin-left:1em;padding:0.5em;font-size:0.8em;border-radius:0.5em">削除</button></form>';
} else {
  $delete_link = "";
}

//イイネ数
if ($SETTING['show_likes']) {
  if ($row['like'] ?? 0 == 1) {
    $article['show_likes'] = "<span class='show_like_count'><i id='like-heart-show' class='fa-heart fa-solid'></i> {$row['like']}</span><br>";
  } else {
    $article['show_likes'] = "";
  }
} else {
  $article['show_likes'] = "";
}


//画像一覧を取得
try {
  $stmt = $db->prepare('SELECT * FROM images Where article_id= :id Order by sort ASC');
  $stmt->bindValue(':id',  $target);
  $result = $stmt->execute();

  $previews = "";
  $firstPreview = "";
  $idx = 1;
  if ($advance_mode) {
    //HTML内で画像を指定
    $images = array();
    while ($row = $result->fetchArray()) {
      if ($firstPreview == "") {
        //1枚目の画像をTwitterCard サムネイル用とする
        $firstPreview = h($row["thumb_l_name"]);
      }
      $images[$idx] = $row;
      $idx++;
    }
    $comment = convertCommands($comment, $images, $index);
  } else {
    //ノーマルモード 先頭からソート順に画像を表示
    while ($row = $result->fetchArray()) {
      $thumb_file_name = h($row["thumb_l_name"]);
      if ($firstPreview == "") {
        //1枚目の画像をTwitterCard サムネイル用とする
        $firstPreview =  $thumb_file_name;
      }
      if ($row['type'] == "video") {
        $img = '<div class="view-image-container"><video controls class="view-image" src="./images/' . h($row["file_name"])  . '"' .
          ' data-src="./images/' .  h($row["file_name"])  . '" width=' .  h($row["thumb_l_width"]) . ' height=' .  h($row["thumb_l_height"]) .
          ' data-width="' . h($row["width"]) . '" data-height="' . h($row["height"]) . '"></div>';
      } else {
        $img = '<div class="view-image-container"><img class="view-image" src="./images/' . $thumb_file_name  . '"' .
          ' data-src="./images/' .  h($row["file_name"])  . '" width=' .  h($row["thumb_l_width"]) . ' height=' .  h($row["thumb_l_height"]) .
          ' data-width="' . h($row["width"]) . '" data-height="' . h($row["height"]) . '"></div>';
      }
      $previews = $previews . $img;
      $idx++;
    }
    $comment = convertCommands($comment, [], $index);
  }
  $article["previews"] = $previews;
  //改行を<BR>に変換
  $comment = convertLineBreaks($comment);
} catch (Exception $ex) {
  $db->close();
  echo 'システムエラーが発生しました<br>';
  $error = $ex->getTraceAsString();
  exit;
}
$article['comment'] = $comment;



//前後リンク
$prev = "";
$next = "";
if ($SETTING["move_link_type"] > 0) {
  $created_at = $article['created_at'];
  try {
    //次の行を取得する
    switch ($SETTING["move_link_type"]) {
      case 1:
        //無条件
        $nextdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at > :created_at order by created_at asc limit 1');
        $nextdb->bindValue(':created_at',  $created_at);
        $prevdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at < :created_at order by created_at desc limit 1');
        $prevdb->bindValue(':created_at',  $created_at);
        break;

      case 3:
        //プライマリタグで前後
        $nextdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at > :created_at and tags like :tag order by created_at asc limit 1');
        $nextdb->bindValue(':created_at',  $created_at);
        $nextdb->bindValue(':tag',  "%" . $primary_tag . "%");
        $prevdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at < :created_at and tags like :tag order by created_at desc limit 1');
        $prevdb->bindValue(':created_at',  $created_at);
        $prevdb->bindValue(':tag',  "%" . $primary_tag . "%");
        break;
      case 2:
        //タグの完全一致で前後
        $where = "";
        foreach ($tags_raw as $idx => $tag) {
          $where = $where . " and tags like :tag$idx";
        }

        $nextdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at > :created_at ' . $where . ' order by created_at asc limit 1');
        $nextdb->bindValue(':created_at',  $created_at);
        $prevdb = $db->prepare('SELECT * From articles Where hidden != 1 and style != 99 and  created_at < :created_at ' . $where . ' order by created_at desc limit 1');
        $prevdb->bindValue(':created_at',  $created_at);
        foreach ($tags_raw as $idx => $tag) {
          $nextdb->bindValue(":tag$idx",  "%" . $tag . "%");
          $prevdb->bindValue(":tag$idx", "%" . $tag . "%");
          echo "%" . $tag . "%";
        }
        break;
    }
    //次の行を取得する
    $result = $nextdb->execute();

    if (!$row = $result->fetchArray()) {
      //新しい行が存在しない
      $next = "-";
    } else {
      $next = '<a href="./view.php?id=' . h($row['id']) . '&back_url=' . $BACK_URL . '">次へ</a>';
    }
    //前の行を取得する
    $result = $prevdb->execute();
    if (!$row = $result->fetchArray()) {
      //新しい行が存在しない
      $prev = "-";
    } else {
      $prev = '<a href="./view.php?id=' . h($row['id']) . '&back_url=' . $BACK_URL . '">前へ</a>';
    }
  } catch (Exception $ex) {
    $db->close();
    echo 'システムエラーが発生しました<br>';
    $error = $ex->getTraceAsString();
    exit;
  }
}

//トップページ用処理
$home_menu = "";
$accounts = array();
if ($style == 99) {
  //メニュー読み取り
  $home_menu = "";
  $result = $db->query('SELECT id, created_at, title, comment, tags, nsfw From articles' .
    ' Where style=99 ORDER BY created_at DESC');
  while ($row = $result->fetchArray()) {
    if ($row['id'] == $target) {
      $home_menu = $home_menu . "<li  class='home_menu_item home_menu_item_current' data-id='{$row['id']}'>{$row['title']}</li>";
    } else {
      $home_menu = $home_menu . "<li  class='home_menu_item' data-id='{$row['id']}'>{$row['title']}</li>";
    }
  }
  if ($home_menu != "") {
    $home_menu = '<ul class="home_menu"><li class="home_menu_item" data-id="home">HOME</li>' . $home_menu . '</ul>';
  }

  //SNSリンク
  $account_rows = $db->query('SELECT * FROM accounts');
  while ($row = $account_rows->fetchArray()) {
    $accounts[] = $row;
  }
}


$db->close(); //DBクローズ

//表示モードの確定
// HTML FULLの場合 : タイトル / タグ / コメント（HTML）
// 画像がある場合　 : タイトル / コメント / タグ / 画像
// 画像がない場合　 : タイトル / タグ / コメント
$mode = "normal";
if ($advance_mode) {
  $mode = "advance";
} else if ($previews == "") {
  $mode = "text";
}
$article['mode'] = $mode;

//Twitterカード用
$document['card_title'] = $article['title'] . " - " . $SETTING['site_title'];
$card_comment = preg_replace("/\r|\n|\r\n/", "", strip_tags($comment));
if (mb_strlen($card_comment) > 100) {
  $card_comment = mb_substr($card_comment, 0, 100, 'UTF-8') . '…';
}
$document['card_comment'] = $card_comment;
$document['card_type'] = "summary";
$document['card_thumbail'] = "";
if ($nsfw) {
  //NSFWコンテンツの場合ogimage
  $article['nsfw'] = true;
  if ($SETTING['use_ogimage']) {
    $document['card_type'] = "summary_large_image";
    $document['card_thumbail'] = $PATH_INFO["url_dir"] . '/images/ogimage.jpg';
  }
} else {
  //画像ありの場合は1枚目を指定
  if ($firstPreview != "") {
    $document['card_type'] = "summary_large_image";
    $document['card_thumbail'] = $PATH_INFO["url_dir"] . '/images/' . $firstPreview;
  } else if ($SETTING['use_ogimage']) {
    $document['card_type'] = "summary_large_image";
    $document['card_thumbail'] = $PATH_INFO["url_dir"] . '/images/ogimage.jpg';
  } else if ($SETTING['use_banner']) {
    $document['card_type'] = "summary_large_image";
    $document['card_thumbail'] = $PATH_INFO["url_dir"] . '/images/banner.jpg';
  }
}


//UIレンダリング
require_once('./module/NoSixTemplate.php');
if ($style == 99) {
  if (file_exists('./env/templates/template_index_article.php')) {
    $template = new NoSixTemplate('template_index_article.php', './env/templates');
  } else {
    $template = new NoSixTemplate('template_index_article.php', './templates');
  }
} else {
  if (file_exists('./env/templates/template_index.php')) {
    //ユーザーテンプレートがある場合はそちらを採用する
    $template = new NoSixTemplate('template_view.php', './env/templates/');
  } else {
    $template = new NoSixTemplate('template_view.php', './templates');
  }
}
$template->set_Data('caption', $caption);
$template->set_data('setting', $SETTING); //Array
$template->set_data('home_menu', $home_menu);
$template->set_data('accounts', $accounts); //Array[](url, icon)
$template->set_data('articles', $article); //Array[](id,title,created_at,comment,image)
$template->set_data('document', $document); //Array(max_index,min_index,current_index,article_count,search_words)
$template->set_data('login', $LOGIN);
$template->set_data('move_next', $next);
$template->set_data('move_prev', $prev);
$template->set_data('back_url', $BACK_URL);
$template->set_data('VERSION', $VERSION);
$template->set_Data('delete_link', $delete_link);
if ($static_mode == 1) {
  //staticモード
  $file_name = "./log_{$target}.html";
  ob_start();

  $template->display();

  $output = ob_get_contents();
  ob_end_clean();
  file_put_contents($file_name, $output);
  echo ('{"state":"success", "path", "' . $file_name . '"}');
  exit;
}

$template->display();

//コメント内の特殊記述を変換する
function convertCommands($comment, $rows, $index)
{
  $comment = str_replace('{{', "&#060;&#060;", $comment); //{{ 表記をエスケープ
  $comment = str_replace('}}', "&#062;&#062;", $comment); //}} 表記をエスケープ

  //単純置換
  $comment = preg_replace('/{search:(.*?)}/i', '<a href="./list.php?q=$1">$1</a>', $comment);
  $comment = preg_replace('/{tag:(.*?)}/i', '<a href="./list.php?q=$1" class="tag">#$1</a>', $comment);
  $comment = preg_replace('/{link:(.*?) (.*?)}/i', '<a href="./view.php?id=$1">$2</a>', $comment);
  $comment = preg_replace('/{c}/i', "<div style='clear:both'></div>\r\n", $comment);
  $comment = preg_replace('/{tc}/i', "<span class='text-combine'>", $comment);
  $comment = preg_replace('/{\/tc}/i', "</span>", $comment);
  $comment = preg_replace('/{vt}/i', "<div class='vertical-text'>", $comment);
  $comment = preg_replace('/{\/vt}/i', "</div><span class='vt-controler-1'>a</span> / <span class='vt-controler-2'>a</span> / <span class='vt-controler-3'>a</span>", $comment);
  $comment = preg_replace('/\{rb\}(.*?)\|(.*?)\{\/rb\}/', '<ruby>$1<rp>(</rp><rt>$2</rt><rp>)</rp></ruby>', $comment);
  $comment = preg_replace('/{border (.*?)}/i', "<style>.view-image{border:1px solid $1;}</style>", $comment);
  $comment = preg_replace('/{border}/i', "<style>.view-image{border:1px solid #555;}</style>", $comment);
  $comment = preg_replace(
    '/{mailform}/i',
    '<div class="mail_form" style="width:80%;margin:0 auto 0 auto"><form action="./api/mail_send.php" method="post" name="inputForm" id="inputForm">お名前<br><input type="text" name="name" class="flat-input" style="width:30em;max-width:90%;"><br>メールアドレス<br><input type="email" name="email" id="email" class="flat-input" style="width:30em;max-width:90%;"><br>コメント<br><textarea name="comment" id="comment" class="flat-input" style="height:10em;"></textarea><input type="text" name="title" style="display:none;"><input type="text" name="from" style="display:none;" value="22view.php"><div class="control" style="text-align:center">  <input type="submit" value="送信" class="button" id="submit"></div></form></div><script>async function postContents(form_data) {  let url = "./api/mail_send.php";  return new Promise((resolve, reject) => {    $.ajax({      type: "POST",      url: url,      data: form_data,      processData: false,      contentType: false,      success: function (response) {        console.log("Success: " + response);        let result = JSON.parse(response);        resolve(result)      },      error: function () {        reject();      }    });  });}$("#submit").on("click", async function (e) {  e.preventDefault();    if($("#comment").val().trim() == "")    {        $("body").showDialog("コメントを入力してください", "OK");	    return    }    let form_data = new FormData($("#inputForm")[0]);form_data.set("comment", btoa(unescape(encodeURIComponent($("#comment").val()))));    postResult = await postContents(form_data);    let dialogText = "<p>" + postResult.msg + "</p>";    $("body").showDialog(dialogText, "OK");});</script>',
    $comment
  );

  $user_agent = $_SERVER['HTTP_USER_AGENT'];
  if (strpos($user_agent, 'iPhone') !== false || strpos($user_agent, 'iPad') !== false || strpos($user_agent, 'Macintosh') !== false) {
    $comment = preg_replace('/―/u', "─", $comment); //iOS safariのフォントの問題でダッシュがつながらないため罫線に変換
    $comment = preg_replace('/(─+)/u', "<span style='text-orientation:mixed;'>$1</span>", $comment); // iOS Safariのバグ対応 縦書きで―が横向きになる問題を修正
  }

  $matches = array();
  preg_match_all('/{([^}]+)}/', $comment, $matches);
  $border = "";

  foreach ($matches[1] as $match) {
    $command_array = explode(" ", str_replace(":", " ", $match));
    $firstCommand = array_shift($command_array);
    //先頭コマンド

    if (is_numeric($firstCommand) && count($rows) >= $firstCommand) {
      //先頭が数字の場合は画像( 本記事のソート番号 )
      $target = "thumb_l";
      $file_name = h($rows[$firstCommand]["file_name"]);
      $type = h($rows[$firstCommand]["type"]);
      $container_s = '<div class="view-image-container">';
      $alt = "";
      foreach ($command_array as $command) {
        if (mb_substr($command, 0, 1) == '"') {
          $alt = 'alt="' . h(str_replace('"', "", $command)) . '"';
          continue;
        }
        switch ($command) {
          case "s":
            $target = 'thumb';
            break;
          case "l":
            $container_s = '<div class="view-image-left">';
            break;
          case "r":
            $container_s = '<div class="view-image-right">';
            break;
          case "c":
            $container_s = '<div class="view-image-container">';
            break;
          case "b":
            $border = " view-image-border";
          default:

            break;
        }
      }
      if ($type == "video") {
        $tag = $container_s . '<video controls class="view-image ' . $border . '" src="./images/' . $file_name  .
          '"  data-type="' . $type . '" data-src="./images/' .  $file_name  . '" width="' . $rows[$firstCommand][$target . "_width"]  . '" height="' . $file_name . '" ' . $alt .
          ' data-width="' . $rows[$firstCommand]["width"] . '" data-height="' . $rows[$firstCommand]["height"]  . '"></div>';
      } else {
        $tag = $container_s . '<img class="view-image ' . $border . '" src="./images/' . $rows[$firstCommand][$target . "_name"]  .
          '"  data-type="' . $type . '" data-src="./images/' .  $file_name  . '" width="' . $rows[$firstCommand][$target . "_width"]  . '" height="' . $rows[$firstCommand][$target . "_height"] . '" ' . $alt .
          ' data-width="' . $rows[$firstCommand]["width"] . '" data-height="' . $rows[$firstCommand]["height"]  . '"></div>';
      }
      $comment = str_replace('{' . $match . '}', $tag, $comment);
    } else if ($firstCommand == "article_list") {
      //記事一覧 引数は タグ名（検索する文字）、 sort("desc","asc")、スタイル(image,text)
      $arg_count = count($command_array);
      $search = $command_array[0];
      $arg_count >= 2  ? $sort = $command_array[1] : $sort = "asc";
      $arg_count >= 3  ? $style = $command_array[2] : $style = "";
      $arg_count >= 4  ? $records_per_page = $command_array[3] : $records_per_page  = 999;

      $tmp = get_article_list($search, $sort, $style, $records_per_page, $index);
      $comment = str_replace('{' . $match . '}', $tmp, $comment);
    } else {
      //解釈不能
      //$comment = str_replace('{' . $match . '}', '', $comment);
    }
  }
  $comment = str_replace("&#060;&#060;", '{',  $comment); //{{ 表記のエスケープを復元
  $comment = str_replace("&#062;&#062;", '}',  $comment); //}} 表記のエスケープを復元
  return $comment;
}

function get_article_list($searchs, $order, $style, $records_per_page, $index)
{
  global $NSFW_CONSENT;
  global $target;
  global $db;

  $order = strtolower($order);
  if ($order != "asc" && $order != "desc") {
    $order = "asc";
  }

  $offset = ($index - 1)  * $records_per_page;
  try {

    $article_count = 0;
    if ($searchs == '') {
      //検索なし
      //hidden指定されていない記事を$records_per_page分取得する
      $article_count = $db->querySingle('SELECT Count(id) as count From articles WHERE hidden != 1 ');
      $pages = ceil($article_count / $records_per_page);
      $result = $db->query('SELECT id, created_at, title, comment, tags, nsfw From articles  Where hidden != 1  ORDER BY created_at ' . $order . ' DESC LIMIT ' .  $records_per_page . ' OFFSET ' . $offset);
    } else {
      //検索条件あり
      //検索条件に従って記事を検索する。スペース区切りで複数指定があった場合はAND条件とする。
      //検索条件式の構築
      $search_list = '';
      $search_Idx = 0;
      foreach (explode(' ', $searchs) as $search) {
        $search_list = $search_list .  " and  tags like :search{$search_Idx}";
      }

      //検索結果数の取得
      $stmt = $db->prepare('SELECT Count(id) as count From articles WHERE hidden != 1 ' . $search_list);
      foreach (explode(' ', $searchs) as $search_Idx => $search) {
        $stmt->bindValue(":search{$search_Idx}",  '%' . $search . '%');
      }
      $result = $stmt->execute();
      $row = $result->fetchArray(); //結果は常に1行
      $article_count = $row['count'];
      $pages = ceil($article_count / $records_per_page);

      //記事の取得
      $stmt = $db->prepare('SELECT id, created_at, title, comment, tags, nsfw From articles WHERE hidden != 1 ' . $search_list  .
        ' ORDER BY created_at ' .  $order  .  ' LIMIT ' . $records_per_page . ' OFFSET ' . $offset);
      foreach (explode(' ', $searchs) as $search_Idx => $search) {
        $stmt->bindValue(":search{$search_Idx}",  '%' . $search . '%');
      }

      $result = $stmt->execute();
    }

    switch ($style) {
      case "images":
        $list_html = "<div class='loglist_images'>";
        break;
      case "thumbs":
        $list_html = "<ul class='loglist_thumbs'>";
        break;
      case "text":
        $list_html = "<ul class='loglist'>";
        break;
      default:
        $list_html = "<ul class='loglist'>";
    }
    while ($row = $result->fetchArray()) {
      $created_at = h($row['created_at']);
      $title = h($row['title']);
      $id = h($row['id']);
      $comment = $row['comment'];
      $nsfw = $row['nsfw'] ?? false;
      //タグクラウド
      $tags = "";
      foreach (explode(' ', $row['tags']) as $tag) {
        if ($tag != "") {
          if (substr($tag, 0, 1) == "-") {
            continue;
            //$tag = substr($tag, 1);
          }
          $tags = $tags . "<a href='./list.php?q={$tag}'>#{$tag}</a> ";
        }
      }

      if ($id == $target) {
        //この記事自体は対象にしない
        continue;
      }
      if ($comment) {
        preg_match('/{caption}(.*?){\/caption}/si', $comment, $match);
        if ($match) {
          //キャプションがある場合はそれを使用
          $comment = $match[1];
        }
        $comment = mb_substr(strip_tags($comment), 0, 100);
        //特殊記述の削除
        $comment = preg_replace('/\{.*\}/', '', $comment);
        $comment = strip_tags($comment);
      }
      if ($style == "images") {
        if ($nsfw && !$NSFW_CONSENT) {
          $list_html = $list_html . "<div class='view-image-nsfw-container'><a href='./view.php?id={$id}'><div class='thumb-box' style=\"background-image:url('./resource/nsfw.png')\"></div></a></div>";
        } else {
          $thumbs = $db->query('SELECT * FROM images where article_id = ' . $id . ' order by sort asc');

          $img = "";
          while ($trow = $thumbs->fetchArray()) {
            $thumb_file_name = h($trow["thumb_l_name"]);
            $img = '<div class="view-image-container"><img class="view-image" src="./images/' . $thumb_file_name  . '"' .
              ' data-src="./images/' .  h($trow["file_name"])  . '" width=' .  h($trow["thumb_l_width"]) . ' height=' .  h($trow["thumb_l_height"]) .
              ' data-width="' . h($trow["width"]) . '" data-height="' . h($trow["height"]) . '"></div>';
            $list_html = $list_html . $img;
          }
        }
      } else if ($style == "text") {
        if ($nsfw && !$NSFW_CONSENT) {
          $title = '<span class="nsfw-titile">[NSWF]</span>' . $title;
        }
        $list_html = $list_html . "<li class='text'><a href='./view.php?id={$id}'><div class='search-list-info'><span class='created_at'>{$created_at}</span><span class='title'>{$title}</span><div class='tags'>{$tags}</div><span class='comment'>{$comment}</span></div></a></li>";
      } else {
        if ($nsfw && !$NSFW_CONSENT) {
          $img = "<div class='list-thumb-box' style=\"background-image:url('./resource/nsfw.png')\"></div>";
          $list_html = $list_html . "<li><a href='./view.php?id={$id}'>{$img}<div class='search-list-info'><span class='created_at'>{$created_at}</span><span class='title'>{$title}</span><div class='tags'>{$tags}</div><span class='comment'>{$comment}</span></div></a></li>";
        } else {
          $thumbs = $db->query('SELECT * FROM images where article_id = ' . $id . ' order by sort asc');
          $trow = $thumbs->fetchArray();
          $img = "";
          if ($trow) {
            $file_name = h($trow['thumb_name']);
            $img = "<div class='list-thumb-box' style=\"background-image:url('./images/$file_name')\"></div>";
          } else {
            $img = "<div class='list-thumb-text'></div>";
          }
          $list_html = $list_html . "<li><a href='./view.php?id={$id}'>{$img}<div class='search-list-info'><span class='created_at'>{$created_at}</span><span class='title'>{$title}</span><div class='tags'>{$tags}</div><span class='comment'>{$comment}</span></div></a></li>";
        }
      }
    }

    $indexser = "<div class='pager'>";
    if ($pages > 1) {
      for ($i = 1; $i <= $pages; $i++) {
        if ($i == $index) {
          $indexser = $indexser . '<span class="pager-current-index">' . $i . '</span> ';
        } else {
          $indexser = $indexser . '<a href="view.php?id=' . $target . '&page=' . $i . '">' . $i . '</a> ';
        }
      }
    }
    $indexser .= "</div>";

    return $list_html . "</ul>" . $indexser;
  } catch (Exception $e) {
    echo $e->getMessage();
  }
}
